@@ -1,7 +1,5 @@
 #' Get GHCND daily data from NOAA FTP server
 #'
-#' @importFrom tidyr gather
-#' @importFrom dplyr %>% rbind_all select mutate rename tbl_df filter bind_rows
 #' @export
 #'
 #' @param stationid Stationid to get
@@ -176,15 +174,17 @@ print.ghcnd_stations <- function(x, ..., n = 10){
 }
 
 get_stations <- function(...){
-  res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-stations.txt", ...))
-  df <- read.fwf(textConnection(content(res, "text")), widths = c(11, 9, 11, 7, 33, 5, 10), header = FALSE, strip.white=TRUE, comment.char="", stringsAsFactors=FALSE)
+  res <- GET_retry("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-stations.txt", ...)
+  df <- read.fwf(textConnection(content(res, "text")), widths = c(11, 9, 11, 7, 33, 5, 10),
+                 header = FALSE, strip.white = TRUE, comment.char = "", stringsAsFactors = FALSE)
   nms <- c("id","latitude", "longitude", "elevation", "name", "gsn_flag", "wmo_id")
   setNames(df, nms)
 }
 
 get_inventory <- function(...){
-  res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt", ...))
-  df <- read.fwf(textConnection(content(res, "text")), widths = c(11, 9, 10, 5, 5, 5), header = FALSE, strip.white=TRUE, comment.char="", stringsAsFactors=FALSE)
+  res <- GET_retry("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt", ...)
+  df <- read.fwf(textConnection(content(res, "text")), widths = c(11, 9, 10, 5, 5, 5),
+                 header = FALSE, strip.white = TRUE, comment.char = "", stringsAsFactors = FALSE)
   nms <- c("id","latitude", "longitude", "element", "first_year", "last_year")
   setNames(df, nms)
 }
@@ -192,23 +192,40 @@ get_inventory <- function(...){
 #' @export
 #' @rdname ghcnd
 ghcnd_states <- function(...){
-  res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-states.txt", ...))
-  df <- read.fwf(textConnection(content(res, "text")), widths = c(2, 27), header = FALSE, strip.white=TRUE, comment.char="", stringsAsFactors=FALSE, col.names = c("code","name"))
+  # res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-states.txt", ...))
+  res <- GET_retry("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-states.txt", ...)
+  df <- read.fwf(textConnection(content(res, "text")), widths = c(2, 27),
+                 header = FALSE, strip.white = TRUE, comment.char = "",
+                 stringsAsFactors = FALSE, col.names = c("code","name"))
   df[ -NROW(df) ,]
 }
 
+GET_retry <- function(url, ..., times = 3) {
+  res <- suppressWarnings(GET(url, ...))
+  if (res$status_code > 226) {
+    stat <- 500
+    while (stat > 226) {
+      res <- suppressWarnings(GET(url, ...))
+      stat <- res$status_code
+    }
+  }
+  return(res)
+}
+
 #' @export
 #' @rdname ghcnd
 ghcnd_countries <- function(...){
-  res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-countries.txt", ...))
-  df <- read.fwf(textConnection(content(res, "text")), widths = c(2, 47), header = FALSE, strip.white=TRUE, comment.char="", stringsAsFactors=FALSE, col.names = c("code","name"))
+  res <- GET_retry("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-countries.txt", ...)
+  df <- read.fwf(textConnection(content(res, "text")), widths = c(2, 47),
+                 header = FALSE, strip.white = TRUE, comment.char = "",
+                 stringsAsFactors = FALSE, col.names = c("code","name"))
   df[ -NROW(df) ,]
 }
 
 #' @export
 #' @rdname ghcnd
 ghcnd_version <- function(...){
-  res <- suppressWarnings(GET("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-version.txt", ...))
+  res <- GET_retry("ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-version.txt", ...)
   content(res, "text")
 }
 
